# Cleez

[![image](https://img.shields.io/pypi/v/cleez.svg)](https://pypi.python.org/pypi/cleez)

[![Documentation Status](https://readthedocs.org/projects/cleez/badge/?version=latest)](https://cleez.readthedocs.io/en/latest/?version=latest)


## Abilian Cleez

Simple framework for building command line applications with multiple
commands and subcommands.

Similar to Cleo, but based on the stdlib\'s argparse module.

- Free / open source software: Apache Software License 2.0
- Documentation: <https://cleez.readthedocs.io>. (nope!)


### Features

- Provides a simple framework for building command line applications with multiple commands and subcommands.

- Based on the stdlib\'s argparse module.

  - Supports command options and arguments.
  - Supports command arguments validation.

- ANSI color output.



### Upcoming features

- Command aliases.
- Command arguments completion.
- Better help messages



### Used by

Cleez is currently used by several projects:

- [Nua](https://github.com/abilian/nua) - an Open source PaaS and application marketplace
- [Abilian Developer Tools](https://github.com/abilian/abilian-devtools) -
- (Add yours)


### Alternatives

- Click
- Typer
- [Clizy](https://github.com/getclizy/clizy)
- [Mando](https://github.com/rubik/mando)
- [dephell-argparse](https://pypi.org/project/dephell-argparse/)



### Credits

This package was created with [Cruft](https://cruft.github.io/cruft/) and the
[abilian/cookiecutter-abilian-python](https://github.com/abilian/cookiecutter-abilian-python)
project template.
